@@ -6,7 +6,7 @@ from .data import texts
 
 nlp = spacy.load("nl_core_news_sm")
 
-nlp.add_pipe("xx_coref", config={"model_name": "xlm_roberta"})
+nlp.add_pipe("xx_coref", config={"model_name": "minilm"})
 
 for doc in nlp.pipe(texts):
     print(doc._.coref_clusters)
